@@ -183,16 +183,18 @@ class Processor(ast.NodeVisitor):
         return [import_symbol(s, cwd=self._cwd).parse_obj(a) for s, a in branches]
 
     def visit_for(self, node: ast.ForNode) -> List[Any]:
-        if isinstance(node.iterable.data, int):
-            iterable = list(range(node.iterable.data))
-        else:
+        if isinstance(node.iterable.data, str):
             iterable = py_.get(self._context, node.iterable.data)
+        else:
+            iterable = node.iterable.data
 
         if isinstance(iterable, int):
             iterable = list(range(iterable))
 
         if not isinstance(iterable, Iterable):
-            if not py_.has(self._context, node.iterable.data):
+            if isinstance(node.iterable.data, str) and not py_.has(
+                self._context, node.iterable.data
+            ):
                 raise ChoixeProcessingError(
                     f"Loop variable `{node.iterable.data}` not found in context"
                 )
