@@ -5,7 +5,7 @@ from urllib.parse import ParseResult
 
 import pydantic as pyd
 
-from pipelime.utils.pydantic_types import ItemType
+from pipelime.utils.pydantic_types import SampleValidationInterface
 
 
 class PydanticFieldMixinBase:
@@ -232,171 +232,6 @@ class GrabberInterface(PydanticFieldWithDefaultMixin, pyd.BaseModel, extra="forb
             worker_init_fn=worker_init_fn,
         )
 
-
-class ItemValidationModel(
-    pyd.BaseModel, extra="forbid", copy_on_model_validation="none"
-):
-    """Item schema validation."""
-
-    class_path: ItemType = pyd.Field(
-        ...,
-        description=(
-            "The item class path. The default package `pipelime.item` can be omitted"
-        ),
-    )
-    is_optional: bool = pyd.Field(
-        True, description="Whether the item is required or optional."
-    )
-    is_shared: bool = pyd.Field(False, description="Whether the item is shared or not.")
-    validator_: t.Optional[str] = pyd.Field(
-        None,
-        description=(
-            "A class path to a callable accepting the item value and either returning "
-            "a validated value or raising an exception in case of error."
-        ),
-        alias="validator",
-    )
-
-    _validator_callable = pyd.PrivateAttr()
-
-    def __init__(self, **data):
-        from pipelime.choixe.utils.imports import import_symbol
-
-        super().__init__(**data)
-
-        def _identity(v):
-            return v
-
-        self._validator_callable = (
-            import_symbol(self.validator_) if self.validator_ else _identity
-        )
-
-    def make_field(self, key_name: str):
-        return (
-            self.class_path.itype,
-            pyd.Field(default_factory=self.class_path.itype, alias=key_name)
-            if self.is_optional
-            else pyd.Field(..., alias=key_name),
-        )
-
-    def make_validator_method(self, field_name: str):
-        import uuid
-
-        # we need random names and dynamic function creation
-        # to avoid reusing the same function name for validators
-        # (yes, pydantic is really pedantic...)
-        rnd_name = uuid.uuid1().hex
-
-        _validator_wrapper = (
-            "def validate_{}_fn(cls, v):\n".format(rnd_name)
-            + "    if v.is_shared != {}:\n".format(self.is_shared)
-            + "        raise ValueError(\n"
-            + "            'Item must{}be shared.'\n".format(
-                " not " if not self.is_shared else " "
-            )
-            + "        )\n"
-            + "    return user_validator_{}(v)\n".format(rnd_name)
-        )
-
-        local_scope = {
-            **globals(),
-            f"user_validator_{rnd_name}": self._validator_callable,
-        }
-        exec(_validator_wrapper, local_scope)
-        fn_helper = local_scope[f"validate_{rnd_name}_fn"]
-        return pyd.validator(field_name)(fn_helper)
-
-
-class SampleValidationInterface(
-    pyd.BaseModel, extra="forbid", copy_on_model_validation="none"
-):
-    """Sample schema validation."""
-
-    sample_schema: t.Union[str, t.Mapping[str, ItemValidationModel]] = pyd.Field(
-        ...,
-        description=(
-            "The sample schema to validate, ie, a mapping from sample keys to expected "
-            "item types.\nThe schema can be a class path to a pydantic model where "
-            "fields' names are the sample keys, while fields' values are the item "
-            "types. Otherwise, an explicit `key-name: ItemValidationModel` mapping "
-            "must be provided."
-        ),
-    )
-    ignore_extra_keys: bool = pyd.Field(
-        True,
-        description=(
-            "When `sample_schema` is an explicit mapping, if `ignore_extra_keys` is "
-            "True, unexpected keys are ignored. Otherwise an error is raised."
-        ),
-    )
-    lazy: bool = pyd.Field(
-        True, description="If True, samples will be validated only when accessed."
-    )
-    max_samples: int = pyd.Field(
-        1,
-        description=(
-            "When the validation is NOT lazy, "
-            "only the slice `[0:max_samples]` is checked. "
-            "Set to 0 to check all the samples."
-        ),
-    )
-
-    _schema_model: t.Type[pyd.BaseModel] = pyd.PrivateAttr()
-
-    def _import_schema(self, schema_path: str):
-        from pipelime.choixe.utils.imports import import_symbol
-
-        imported_schema = import_symbol(schema_path)
-        if not issubclass(imported_schema, pyd.BaseModel):
-            raise ValueError(f"`{schema_path}` is not a pydantic model.")
-        return imported_schema
-
-    def _make_schema(self, schema_def: t.Mapping[str, ItemValidationModel]):
-        class Config(pyd.BaseConfig):
-            arbitrary_types_allowed = True
-            extra = pyd.Extra.ignore if self.ignore_extra_keys else pyd.Extra.forbid
-
-        def _safe_name(k):
-            return f"{k}___"
-
-        _item_map = {_safe_name(k): v.make_field(k) for k, v in schema_def.items()}
-        _validators = {
-            f"validate_{k}": v.make_validator_method(_safe_name(k))
-            for k, v in schema_def.items()
-        }
-
-        return pyd.create_model(
-            "SampleSchema",
-            __config__=Config,
-            __validators__=_validators,
-            **_item_map,
-        )
-
-    def __init__(self, **data):
-        super().__init__(**data)
-        self._schema_model = (
-            self._import_schema(self.sample_schema)
-            if isinstance(self.sample_schema, str)
-            else self._make_schema(self.sample_schema)
-        )
-
-    def append_validator(self, sequence):
-        return sequence.validate_samples(
-            sample_schema=self._schema_model,
-            lazy=self.lazy,
-            max_samples=self.max_samples,
-        )
-
-    def as_pipe(self):
-        return {
-            "validate_samples": {
-                "sample_schema": self._schema_model,
-                "lazy": self.lazy,
-                "max_samples": self.max_samples,
-            }
-        }
-
-
 class InputDatasetInterface(
     PydanticFieldNoDefaultMixin,
     pyd.BaseModel,
@@ -813,6 +648,7 @@ class ToyDatasetInterface(
     objects_range: t.Tuple[int, int] = pyd.Field(
         (1, 5), description="The (min, max) number of objects in each sample."
     )
+    seed: t.Optional[int] = pyd.Field(None, description="The optional random seed.")
 
     @pyd.validator("key_format")
     def validate_key_format(cls, v):
@@ -835,4 +671,5 @@ class ToyDatasetInterface(
             key_format=self.key_format,
             max_labels=self.max_labels,
             objects_range=self.objects_range,
+            seed=self.seed,
         )
